@@ -37,6 +37,16 @@ ACTION_LIST_CREATE = 'createList'
 ACTION_LIST_REMOVE = 'deleteList'
 ACTION_LIST_RENAME = 'renameList'
 
+ACTION_GET_MASTER_LIST = 'getMasterList'
+ACTION_GET_CATEGORY_LIST = 'getCategoryList'
+ACTION_ITEM_RENAME = 'changeItemValue'
+
+ACTION_ITEM_CHANGE_VALUE = 'changeItemValue'
+ACTION_LIST_DELETE_ALL_CROSSED_OFF = 'deleteAllCrossedOffItems'
+REGEX_MASTER_LIST_ID = r'href="list/(.*)">Manage master list'
+ATTR_CATEGORY_ID = 'categoryId'
+ATTR_ITEM_NEW_VALUE = 'newValue'
+
 
 # regex to get team id
 REGEX_TEAM_ID = r'g_teamId = "(.*)";'
@@ -54,7 +64,6 @@ ATTR_ITEM_CATEGORY = 'categoryId'
 ATTR_COMMAND = 'command'
 ATTR_TEAM_ID = 'teamId'
 
-
 # properties of returned data
 PROP_LIST = 'list'
 PROP_ITEMS = 'items'
@@ -78,6 +87,7 @@ class OurGroceries():
         """Logs into Our Groceries."""
         await self._get_session_cookie()
         await self._get_team_id()
+        await self._get_master_list_id()
         _LOGGER.debug('ourgroceries logged in')
 
     async def _get_session_cookie(self):
@@ -112,6 +122,16 @@ class OurGroceries():
                 self._category_id = categoryList['id']
                 _LOGGER.debug('ourgroceries found category_id {}'.format(self._category_id))
 
+    async def _get_master_list_id(self):
+        """Gets the master list id for a user."""
+        _LOGGER.debug('ourgroceries _get_master_list_id')
+        cookies = {COOKIE_KEY_SESSION: self._session_key}
+        async with aiohttp.ClientSession(cookies=cookies) as session:
+            async with session.get(YOUR_LISTS) as resp:
+                responseText = await resp.text()
+                self._master_list_id = re.findall(REGEX_MASTER_LIST_ID, responseText)[0]
+                _LOGGER.debug('ourgroceries found master_list_id {}'.format(self._master_list_id))
+
     async def get_my_lists(self):
         """Get our grocery lists."""
         _LOGGER.debug('ourgroceries get_my_lists')
@@ -160,7 +180,7 @@ class OurGroceries():
         }
         return await self._post(ACTION_ITEM_CROSSED_OFF, other_payload)
 
-    async def add_item_to_list(self, list_id, value, category="uncategorized"):
+    async def add_item_to_list(self, list_id, value, category="uncategorized", auto_category=False):
         """Add a new item to a list."""
         _LOGGER.debug('ourgroceries add_item_to_list')
         other_payload = {
@@ -168,6 +188,8 @@ class OurGroceries():
             ATTR_ITEM_VALUE: value,
             ATTR_ITEM_CATEGORY: category,
         }
+        if auto_category:
+            other_payload.pop(ATTR_ITEM_CATEGORY, None)
         return await self._post(ACTION_ITEM_ADD, other_payload)
 
     async def remove_item_from_list(self, list_id, item_id):
@@ -179,6 +201,57 @@ class OurGroceries():
         }
         return await self._post(ACTION_ITEM_REMOVE, other_payload)
 
+    async def get_master_list(self):
+        """Get an our grocery list's items."""
+        _LOGGER.debug('ourgroceries get_list_items')
+        other_payload = {ATTR_LIST_ID: self._master_list_id}
+        return await self._post(ACTION_GET_LIST, other_payload)
+
+    async def get_category_list(self):
+        """Get our grocery lists."""
+        _LOGGER.debug('ourgroceries get_master_list')
+        other_payload = {ATTR_TEAM_ID: self._team_id}
+        return await self._post(ACTION_GET_CATEGORY_LIST, other_payload)
+
+    async def delete_list(self, list_id):
+        """Create a new shopping list."""
+        _LOGGER.debug('ourgroceries create_list')
+        other_payload = {
+            ATTR_LIST_ID: list_id,
+            ATTR_TEAM_ID: self._team_id,
+        }
+        return await self._post(ACTION_LIST_REMOVE, other_payload)
+
+    async def delete_all_crossed_off_from_list(self, list_id):
+        """delete all crossed off itemsn from a list."""
+        _LOGGER.debug('ourgroceries remove_item_from_list')
+        other_payload = {
+            ATTR_LIST_ID: list_id,
+        }
+        return await self._post(ACTION_LIST_DELETE_ALL_CROSSED_OFF, other_payload)
+
+    async def add_item_to_master_list(self, value, category_id):
+        """Add a new item to a list."""
+        _LOGGER.debug('ourgroceries add_item_to_list')
+        other_payload = {
+            ATTR_LIST_ID: self._master_list_id,
+            ATTR_ITEM_VALUE: value,
+            ATTR_CATEGORY_ID: category_id,
+        }
+        return await self._post(ACTION_ITEM_ADD, other_payload)
+
+    async def change_item_on_list(self, list_id, item_id, category_id, value):
+        """Add a new item to a list."""
+        _LOGGER.debug('ourgroceries add_item_to_list')
+        other_payload = {
+            ATTR_ITEM_ID: item_id,
+            ATTR_LIST_ID: list_id,
+            ATTR_ITEM_NEW_VALUE: value,
+            ATTR_CATEGORY_ID: category_id,
+            ATTR_TEAM_ID: self._team_id,
+        }
+        return await self._post(ACTION_ITEM_CHANGE_VALUE, other_payload)
+
     async def _post(self, command, other_payload=None):
         """Post a command to the API."""
         if not self._session_key:
